# Description

This GUI plugin allows you to do track analysis by using autoencoder models that convert the segmentation labels to point cloud representations. It takes
a TrackMate generated XML and csv files and creates a master XML file by computing additional shape and dynamic features based on the generated point clouds. 


Elaborate documentation for users of this repository at this website [documentation]

# Who is This For?

This plugin is intended to be used on 3D+time tracking data for researchers interested in performing cell-fate analysis for which the shape and dynamic features of cells in a track are relevant.

# How to Guide

You will need to have a segmentation image in 3D generated by VollSeg or other such plugins along with tracking XML, spots, edges and tracks csv file 
generated from the Fiji plugin TrackMate. You can either use our autoencoder models to apply on your segmentation image to generate point cloud representations
or upload your torch trained model based on our Lightning based package [Lightning version](https://github.com/Kapoorlabs-CAPED/KapoorLabs-Lightning).



# Getting Help

If you find a bug with affinder, or would like support with using it, please raise an
issue on the [GitHub repository](https://github.com/Kapoorlabs-CAPED/vollseg-napari-trackmate).

# How to Cite

Please use the following citations if you use this in your work:
https://conference.scipy.org/proceedings/scipy2021/varun_kapoor.html


[documentation]: https://kapoorlabs-caped.github.io/vollseg-napari-trackmate
